package nl.rubend.queuetimes

import android.content.Context
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.intPreferencesKey
import androidx.datastore.preferences.core.stringPreferencesKey
import androidx.datastore.preferences.preferencesDataStore
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch
import nl.rubend.queuetimes.data.parks.ParkInfo

class ParkStore(private val context: Context) {
    companion object {
        private val Context.dataStore: DataStore<Preferences> by preferencesDataStore("park")
        private val PARK_ID_KEY = intPreferencesKey("parkId")
        private val PARK_NAME_KEY = stringPreferencesKey("parkName")
    }

    val getParkId: Flow<Int> = context.dataStore.data.map { preferences ->
        preferences[PARK_ID_KEY] ?: -1
    }

    val getParkName: Flow<String> = context.dataStore.data.map { preferences ->
        preferences[PARK_NAME_KEY] ?: ""
    }

    fun savePark(parkInfo: ParkInfo?) {
        CoroutineScope(Dispatchers.IO).launch {
            context.dataStore.edit { preferences ->
                preferences[PARK_ID_KEY] = parkInfo?.id?:-1
                preferences[PARK_NAME_KEY] = parkInfo?.name?:""
            }
        }
    }
}