package nl.rubend.queuetimes.components

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.sp
import io.ktor.client.call.body
import io.ktor.client.request.get
import kotlinx.coroutines.flow.collect
import kotlinx.coroutines.launch
import nl.rubend.queuetimes.ParkStore
import nl.rubend.queuetimes.data.park.Park
import nl.rubend.queuetimes.httpClient

@Composable
fun parkComponent(parkId: Int) {
    val store = ParkStore(LocalContext.current)
    val parkName = store.getParkName.collectAsState("").value
    val scope = rememberCoroutineScope()
    var park: Park? by remember { mutableStateOf(null) }
    var search: String by remember { mutableStateOf("") }
    fun refresh() {
        park = null
        scope.launch {
            park = httpClient.get("nl/parks/$parkId/queue_times.json").body()
        }
    }
    LaunchedEffect(true) {
        refresh()
    }
    Column {
        Row {
            Column {
                Row {
                    Button(onClick = ::refresh) {
                        Text("Refresh")
                    }
                    Button(onClick = { store.savePark(null) }) {
                        Text("Select park")
                    }
                }
                BasicTextField(value = search, onValueChange = { text -> search = text })
            }
            Column {
                Row {
                    Spacer(Modifier.weight(1f))
                    Text(parkName)
                    Spacer(Modifier.weight(1f))
                }
                Spacer(Modifier)
                HyperlinkText(
                    fullText = "Powered by Queue-Times.com",
                    hyperLinks = mutableMapOf(
                        "Queue-Times.com" to "https://queue-times.com/parks/$parkId",
                    ),
                    textStyle = TextStyle(
                        textAlign = TextAlign.Center,
                        color = Color.Gray
                    )
                )
            }
        }
        park?.compose(search)
    }
}