package nl.rubend.queuetimes.data.park

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import kotlinx.datetime.Clock
import kotlinx.datetime.LocalDateTime
import kotlinx.datetime.TimeZone
import kotlinx.datetime.toInstant
import kotlinx.datetime.toLocalDateTime
import kotlinx.serialization.Serializable
import nl.rubend.queuetimes.components.timeView

@Serializable
data class Park(val lands: MutableList<Land>, val rides: List<Ride>) {
    init {
        if(rides.isNotEmpty()) lands.add(
            Land(
                0,
                "global",
                rides,
            )
        )
    }

    @Composable
    fun compose(search: String) {
        var lastUpdated: LocalDateTime? by remember {mutableStateOf(null)}
        LaunchedEffect(true) {
            lastUpdated= Clock.System.now().toLocalDateTime(TimeZone.currentSystemDefault())
        }
        Row {
            Text("Last updated:")
            lands.flatMap { it.rides.map { it.last_updated } }.maxOfOrNull { it }?.let { timeView(it) }
            Text("/")
            lastUpdated?.toInstant(TimeZone.currentSystemDefault())?.let { timeView(it) }
        }
        Column(modifier= Modifier.verticalScroll(rememberScrollState())) {
            lands.sortedBy {it.name}.map { it.compose(search) }
        }
    }
}